@@ -1,5 +1,5 @@
 # xSGE Physics Framework
-# Copyright (C) 2014 Julian Marchant <onpon4@riseup.net>
+# Copyright (C) 2014, 2015 Julian Marchant <onpon4@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -171,7 +171,8 @@ class Collider(sge.Object):
                     stopper = other
 
             if stopper is not None:
-                self.event_physics_collision_right(stopper)
+                move_loss = max(0, abs(move) - abs(self.x - old_x))
+                self.event_physics_collision_right(stopper, move_loss)
                 stopper.event_physics_collision_left(self)
                 
         elif move < 0:
@@ -256,7 +257,8 @@ class Collider(sge.Object):
                     stopper = other
 
             if stopper is not None:
-                self.event_physics_collision_left(stopper)
+                move_loss = max(0, abs(move) - abs(self.x - old_x))
+                self.event_physics_collision_left(stopper, move_loss)
                 stopper.event_physics_collision_right(self)
 
         # Engage stickiness (same whether moving left or right)
@@ -420,7 +422,8 @@ class Collider(sge.Object):
                     stopper = other
 
             if stopper is not None:
-                self.event_physics_collision_bottom(stopper)
+                move_loss = max(0, abs(move) - abs(self.y - old_y))
+                self.event_physics_collision_bottom(stopper, move_loss)
                 stopper.event_physics_collision_top(self)
                 
         elif move < 0:
@@ -505,7 +508,8 @@ class Collider(sge.Object):
                     stopper = other
 
             if stopper is not None:
-                self.event_physics_collision_top(stopper)
+                move_loss = max(0, abs(move) - abs(self.y - old_y))
+                self.event_physics_collision_top(stopper, move_loss)
                 stopper.event_physics_collision_bottom(self)
 
         # Engage stickiness (same whether moving left or right)
@@ -700,48 +704,55 @@ class Collider(sge.Object):
 
         return r
 
-    def event_physics_collision_left(self, other):
+    def event_physics_collision_left(self, other, move_loss):
         """
         Called when the left side of the collider collides with a wall
         or slope in the sense of the physics system, rather than in the
-        sense of SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_left` for more information.
+        sense of SGE collision detection.
+
+        Arguments:
+
+        - ``move_loss`` -- The amount of movement that was prevented by
+          the collision in pixels.  For example, if the object would
+          have moved 6 pixels, but only moved 2 pixels as a result of
+          this collision, this value will be ``4``.  This can be used to
+          undo such a reduction in movement.
+
+        See the documentation for :meth:`sge.Object.event_collision` for
+        more information.
         """
         pass
 
-    def event_physics_collision_right(self, other):
+    def event_physics_collision_right(self, other, move_loss):
         """
         Called when the right side of the collider collides with a wall
         or slope in the sense of the physics system, rather than in the
         sense of SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_right` for more information.
+        :meth:`xsge.physics.Collider.event_physics_collision_left` for
+        more information.
         """
         pass
 
-    def event_physics_collision_top(self, other):
+    def event_physics_collision_top(self, other, move_loss):
         """
         Called when the top side of the collider collides with a wall or
         slope in the sense of the physics system, rather than in the
         sense of SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_top` for more information.
+        :meth:`xsge.physics.Collider.event_physics_collision_left` for
+        more information.
         """
         pass
 
-    def event_physics_collision_bottom(self, other):
+    def event_physics_collision_bottom(self, other, move_loss):
         """
         Called when the bottom side of the collider collides with a wall
         or slope in the sense of the physics system, rather than in the
         sense of SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_bottom` for more information.
+        :meth:`xsge.physics.Collider.event_physics_collision_left` for
+        more information.
         """
         pass
 
-    def event_update_position(self, delta_mult):
-        xmove = self.xvelocity * delta_mult
-        ymove = self.yvelocity * delta_mult
-        self.move_x(xmove)
-        self.move_y(ymove)
-
 
 class SolidLeft(sge.Object):
 
@@ -755,7 +766,7 @@ class SolidLeft(sge.Object):
         Called when the left side of the wall collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_left` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -772,7 +783,7 @@ class SolidRight(sge.Object):
         Called when the right side of the wall collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_right` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -789,7 +800,7 @@ class SolidTop(sge.Object):
         Called when the top side of the wall collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_top` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -806,7 +817,7 @@ class SolidBottom(sge.Object):
         Called when the bottom side of the wall collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_bottom` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -870,7 +881,7 @@ class SlopeTopLeft(sge.Object):
         Called when the left side of the slope collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_left` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -879,7 +890,7 @@ class SlopeTopLeft(sge.Object):
         Called when the top side of the slope collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_top` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -934,7 +945,7 @@ class SlopeTopRight(sge.Object):
         Called when the right side of the slope collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_right` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -943,7 +954,7 @@ class SlopeTopRight(sge.Object):
         Called when the top side of the slope collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_top` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -998,7 +1009,7 @@ class SlopeBottomLeft(sge.Object):
         Called when the left side of the slope collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_left` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -1007,7 +1018,7 @@ class SlopeBottomLeft(sge.Object):
         Called when the bottom side of the slope collides with a
         collider in the sense of the physics system, rather than in the
         sense of SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_left` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -1062,7 +1073,7 @@ class SlopeBottomRight(sge.Object):
         Called when the right side of the slope collides with a collider
         in the sense of the physics system, rather than in the sense of
         SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_right` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -1071,7 +1082,7 @@ class SlopeBottomRight(sge.Object):
         Called when the bottom side of the slope collides with a
         collider in the sense of the physics system, rather than in the
         sense of SGE collision detection.  See the documentation for
-        :meth:`sge.Object.event_collision_bottom` for more information.
+        :meth:`sge.Object.event_collision` for more information.
         """
         pass
 
@@ -1389,11 +1400,3 @@ class MobileWall(sge.Object):
                                          True)
                             self.event_physics_collision_top(other)
                             other.event_physics_collision_bottom(self)
-
-    def event_update_position(self, delta_mult):
-        xmove = self.xvelocity * delta_mult
-        ymove = self.yvelocity * delta_mult
-        if xmove:
-            self.move_x(xmove)
-        if ymove:
-            self.move_y(ymove)
